@@ -24,8 +24,10 @@ The V3 of changelogs.
 """
 
 import enum
+from dataclasses import dataclass
 from typing import List
-from databind.core import datamodel, field
+from typing_extensions import Annotated
+from databind.core import annotations as A
 from . import _ChangelogBase, v1
 
 
@@ -50,9 +52,9 @@ class Type(enum.Enum):
     return self.value[1]
 
 
-@datamodel
+@dataclass
 class Entry:
-  type_: Type = field(altname='type')
+  type_: Annotated[Type, A.alias('type')]
   component: str
   description: str
   fixes: List[str]
@@ -77,5 +79,6 @@ class Changelog(_ChangelogBase[v1.Changelog], List[Entry]):
   Supersedes = v1.Changelog  # _ChangelogBase
 
   @classmethod
-  def adapt(cls, v1_changelog: v1.Changelog) -> 'Changelog':
+  def adapt(cls, v1_changelog: _ChangelogBase) -> 'Changelog':
+    assert isinstance(v1_changelog, v1.Changelog)
     return cls(map(Entry.from_v1, v1_changelog))
