@@ -155,9 +155,9 @@ def make_bump_command(
   @click.option('--patch', is_flag=True, help='bump the patch number')
   @click.option('--post', is_flag=True, help='bump the post-release number')
   @click.option('--snapshot', is_flag=True, help='update the version number by appending the Git commit distance and shasum (note: not compatible with publishing to PyPI)')
-  @click.option('--tag', is_flag=True, help='create a commit and Git tag after bumping the version')
-  @click.option('--push', is_flag=True, help='push the new commit and tag to the Git "origin" remote')
-  @click.option('--dry', is_flag=True, help='do not write changes to disk')
+  @click.option('-t', '--tag', is_flag=True, help='create a commit and Git tag after bumping the version')
+  @click.option('-p', '--push', is_flag=True, help='push the new commit and tag to the Git "origin" remote')
+  @click.option('-d', '--dry', is_flag=True, help='do not write changes to disk')
   @click.option('-w', '--warnings-as-errors', is_flag=True, help='treat check warnings as errors')
   @click.option('--skip-checks', is_flag=True, help='skip running checks before bumping')
   @click.option('--skip-update', is_flag=True, help='skip update after bumping')
