@@ -19,8 +19,10 @@
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 
+from os import name
 import sys
 import time
+from typing import Optional
 
 import click
 from termcolor import colored
@@ -42,12 +44,18 @@ from . import mono, project
   help='Capture the output of the underlying testing framework. If set to false, the output '
        'will be routed to stderr (default: true)')
 @click.option('--only', help='Comma-separated list of packages to test.')
-def test(isolate: bool, keep_test_env: bool, capture: bool, only: str) -> None:
+@click.option('--install/--no-install', default=None,
+  help='Install test requirements required by the driver. This is enabled by default unless this '
+       'command is run not from a virtual environment. Shut performs a minor optimization in that '
+       'it skips the installation if it appears to have installed the dependencies before (you can '
+       'pass --install explicitly to ensure that the test requirements are installed before invoking '
+       'the test drivers).')
+def test(isolate: bool, keep_test_env: bool, capture: bool, only: str, install: Optional[bool]) -> None:
   """
   Run unit tests for all packages in the mono repository.
   """
 
-  monorepo = project.load_or_exit(expect=MonorepoModel)
+  project.load_or_exit(expect=MonorepoModel)
 
   if only:
     packages = []
@@ -56,11 +64,11 @@ def test(isolate: bool, keep_test_env: bool, capture: bool, only: str) -> None:
       if package_name not in package_map:
         sys.exit(f'error: package "{package_name}" does not exist')
       package = package_map[package_name]
-      if not package.test_driver:
+      if not package.get_test_drivers():
         sys.exit(f'error: package "{package_name}" has no test driver configured')
       packages.append(package)
   else:
-    packages = list(filter(lambda p: p.test_driver, project.packages))
+    packages = list(filter(lambda p: p.get_test_drivers(), project.packages))
 
   packages = sorted(packages, key=lambda p: p.name)
 
@@ -80,13 +88,13 @@ def test(isolate: bool, keep_test_env: bool, capture: bool, only: str) -> None:
       print()
     print(f'Testing package {colored(package.name, "yellow", attrs=["bold"])}:')
     print()
-    test_run = test_package(package, isolate, keep_test_env, capture)
-    all_tests += test_run.tests
-    all_errors += test_run.errors
-    print_test_run(test_run)
-    if test_run.status != TestStatus.PASSED:
-      exit_code = 1
-    package_statuses.append((package, test_run.status))
+    for driver_name, test_run in test_package(package, isolate, keep_test_env, capture, install):
+      all_tests += test_run.tests
+      all_errors += test_run.errors
+      print_test_run(test_run)
+      if test_run.status not in (TestStatus.PASSED, TestStatus.SKIPPED):
+        exit_code = 1
+      package_statuses.append((package, driver_name, test_run.status))
 
   n_passed = sum(1 for t in all_tests if t.status == TestStatus.PASSED)
   n_skipped = sum(1 for t in all_tests if t.status == TestStatus.SKIPPED)
@@ -99,8 +107,8 @@ def test(isolate: bool, keep_test_env: bool, capture: bool, only: str) -> None:
         f'{n_skipped} skipped, {len(all_tests) - n_passed} failed, {len(all_errors)} error(s)). '
         f'{"PASSED" if exit_code == 0 else "FAILED"}')
   print()
-  for package, status in package_statuses:
+  for package, run_name, status in package_statuses:
     color = {TestStatus.PASSED: 'green', TestStatus.SKIPPED: 'yellow', TestStatus.FAILED: 'red', TestStatus.ERROR: 'red'}[status]
-    print(f'  {colored(package.name, color, attrs=["bold"])} {status.name}')
+    print(f'  {colored(package.name, color, attrs=["bold"])} ({run_name}): {status.name}')
 
   sys.exit(exit_code)
