@@ -22,14 +22,21 @@
 import abc
 import enum
 import datetime
+import hashlib
 import json
 import os
 import shlex
 import shutil
+import socket
 import subprocess as sp
+import sys
+import textwrap
+import traceback
+import types
 from dataclasses import dataclass, field
-from typing import Optional, List, TYPE_CHECKING
+from typing import Dict, Optional, List, TYPE_CHECKING
 
+from nr.preconditions import check_not_none
 from databind.core import annotations as A
 from shut.model.requirements import Requirement
 
@@ -68,6 +75,14 @@ class StackTrace:
   lineno: int
   message: str
 
+  @classmethod
+  def from_traceback(cls, tb: Optional[types.TracebackType]) -> List['StackTrace']:
+    result = []
+    while tb:
+      result.append(cls(filename=tb.tb_frame.f_code.co_filename, lineno=tb.tb_frame.f_lineno, message=''))
+      tb = tb.tb_next
+    return result
+
 
 @dataclass
 class TestCrashReport:
@@ -77,6 +92,20 @@ class TestCrashReport:
   traceback: List[StackTrace]
   longrepr: str
 
+  @classmethod
+  def current_exception(cls) -> 'TestCrashReport':
+    exc = sys.exc_info()
+    if exc is None:
+      raise RuntimeError('no current exception')
+    tb = exc[2]
+    assert tb
+    return cls(
+      filename=tb.tb_frame.f_code.co_filename,
+      lineno=tb.tb_frame.f_lineno,
+      message=str(exc[1]),
+      traceback=StackTrace.from_traceback(tb),
+      longrepr='\n'.join(traceback.format_exception(*exc)))
+
 
 @dataclass
 class TestCase:
@@ -112,6 +141,9 @@ class Runtime:
   pip: List[str]
   virtualenv: List[str]
 
+  def __post_init__(self) -> None:
+    self._env_info: Optional[Dict[str, Optional[str]]] = None
+
   @classmethod
   def from_env(self) -> 'Runtime':
     python = shlex.split(os.getenv('PYTHON', 'python'))
@@ -127,15 +159,52 @@ class Runtime:
     virtualenv = python + ['-m', 'venv']
     return Runtime(python, pip, virtualenv)
 
+  def is_venv(self) -> bool:
+    """
+    Returns #True if the #Runtime refers to a local environment (e.g. Virtualenv).
+
+    Todo: Detect Conda environments as local environments?
+    """
+
+    # See https://stackoverflow.com/a/42580137/791713
+    info = self._get_environment_info()
+    return bool(info['real_prefix'] or (info['base_prefix'] and info['prefix'] != info['base_prefix']))
+
+  def get_executable_path(self) -> str:
+    return check_not_none(self._get_environment_info()['executable'])
+
+  def get_hash_code(self) -> str:
+    """
+    Returns a has that identifies the runtime. This is a combination of the environment info
+    and the creation timestamp of the Python executable (which we expect to only be changed if
+    a virtualenv is re-created).
+    """
+
+    path = self.get_executable_path()
+    ctime = os.path.getctime(path)
+    return hashlib.md5(f'{socket.gethostname()}-{path}-{ctime}'.encode()).hexdigest()
+
+  def _get_environment_info(self) -> Dict[str, Optional[str]]:
+    if self._env_info is None:
+      code = textwrap.dedent('''
+        import sys, platform, json
+        print(json.dumps({
+          "executable": sys.executable,
+          "version": sys.version,
+          "platform": platform.platform(),
+          "prefix": sys.prefix,
+          "base_prefix": getattr(sys, 'base_prefix', None),
+          "real_prefix": getattr(sys, 'real_prefix', None),
+        }))
+      ''')
+      self._env_info = json.loads(sp.check_output(self.python + ['-c', code]).decode())
+    return self._env_info
+
   def get_environment(self) -> TestEnvironment:
-    env = getattr(self, '_environment', None)
-    if env is None:
-      code = 'import sys, platform, json\n'\
-            'print(json.dumps({"version": sys.version, "platform": platform.platform()}))'
-      raw = json.loads(sp.check_output(self.python + ['-c', code]).decode())
-      env =TestEnvironment(raw['version'], raw['platform'])
-      self._environment = env
-    return env
+    raw = self._get_environment_info()
+    version, platform = raw['version'], raw['platform']
+    assert version and platform
+    return TestEnvironment(version, platform)
 
 
 @dataclass
